'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _isInteger = require('babel-runtime/core-js/number/is-integer');

var _isInteger2 = _interopRequireDefault(_isInteger);

exports.createScreenSizeClassNames = createScreenSizeClassNames;
exports.createScreenSizePropTypes = createScreenSizePropTypes;
exports.createScreenSizeClassNamesFromProps = createScreenSizeClassNamesFromProps;

var _react = require('react');

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function processScreenSizeClassNames() {
  var classNameMapping = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];
  var callback = arguments[1];

  classNameMapping.forEach(function (_ref) {
    var baseClassName = _ref.baseClassName;
    var basePropName = _ref.basePropName;
    var type = _ref.type;
    var min = _ref.min;
    var max = _ref.max;
    var values = _ref.values;
    return _constants.SCREEN_SIZES.forEach(function (size) {
      return callback({ baseClassName: baseClassName, basePropName: basePropName, type: type, min: min, max: max, values: values, size: size });
    });
  });
}

function createScreenSizeClassNames(classNameMapping) {
  var classNames = [];

  processScreenSizeClassNames(classNameMapping, function (_ref2) {
    var baseClassName = _ref2.baseClassName;
    var type = _ref2.type;
    var min = _ref2.min;
    var max = _ref2.max;
    var values = _ref2.values;
    var size = _ref2.size;

    var className = size + (baseClassName ? '-' + baseClassName : '');

    if (type === _constants.CLASS_NAME_TYPES.RANGE) {
      for (var i = min; i <= max; i++) {
        classNames.push(className + '-' + i);
      }
    } else if (type === _constants.CLASS_NAME_TYPES.ENUM) {
      values.forEach(function (value) {
        return classNames.push(className + '-' + value);
      });
    } else {
      classNames.push(className);
    }
  });

  return classNames;
}

function createScreenSizePropTypes(classNameMapping) {
  var propTypes = {};

  processScreenSizeClassNames(classNameMapping, function (_ref3) {
    var basePropName = _ref3.basePropName;
    var type = _ref3.type;
    var values = _ref3.values;
    var size = _ref3.size;

    var propType = _react.PropTypes.bool;
    if (type === _constants.CLASS_NAME_TYPES.RANGE) {
      propType = _react.PropTypes.number;
    } else if (type === _constants.CLASS_NAME_TYPES.ENUM) {
      propType = _react.PropTypes.oneOf(values);
    }

    propTypes['' + size + basePropName] = propType;
  });

  return propTypes;
}

function createScreenSizeClassNamesFromProps(classNameMapping) {
  var props = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var styles = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

  var classNames = {};

  processScreenSizeClassNames(classNameMapping, function (_ref4) {
    var baseClassName = _ref4.baseClassName;
    var basePropName = _ref4.basePropName;
    var type = _ref4.type;
    var min = _ref4.min;
    var max = _ref4.max;
    var values = _ref4.values;
    var size = _ref4.size;

    var propName = '' + size + basePropName;
    var propValue = props[propName];
    var className = size + (baseClassName ? '-' + baseClassName : '');

    if (type === _constants.CLASS_NAME_TYPES.RANGE) {
      if (styles[className + '-' + propValue]) {
        classNames[styles[className + '-' + propValue]] = (0, _isInteger2.default)(propValue) && propValue >= min && propValue <= max;
      }
    } else if (type === _constants.CLASS_NAME_TYPES.ENUM) {
      if (styles[className + '-' + propValue]) {
        classNames[styles[className + '-' + propValue]] = values.includes(propValue);
      }
    } else if (styles[className]) {
      classNames[styles[className]] = propValue;
    }
  });

  return classNames;
}